summaryrefslogtreecommitdiffstats
path: root/libkdegames/kcarddialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kcarddialog.h')
-rw-r--r--libkdegames/kcarddialog.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/libkdegames/kcarddialog.h b/libkdegames/kcarddialog.h
index 7cdc82b6..e0681f5b 100644
--- a/libkdegames/kcarddialog.h
+++ b/libkdegames/kcarddialog.h
@@ -90,6 +90,7 @@ class KCardDialogPrivate;
class KDE_EXPORT KCardDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -103,11 +104,11 @@ public:
/**
* Constructs a card deck selection dialog.
*
* @param parent The parent widget of the dialog, if any.
* @param name The name of the dialog.
* @param flags Specifies whether the dialog is modal or not.
*/
- KCardDialog (TQWidget* parent = NULL,const char* name = NULL,
+ KCardDialog (TQWidget* tqparent = NULL,const char* name = NULL,
CardFlags flags = Both);
/**
* Destructs a card deck selection dialog.
@@ -125,7 +126,7 @@ public:
* @param carddir a reference to the directory name used as front of the
* cards. The directory contains the card images as 1.png to 52.png
*
* @param parent an optional pointer to the parent window of the dialog
*
* @param flags what to show
*
@@ -153,7 +154,7 @@ public:
*
* @return TQDialog::result().
*/
- static int getCardDeck(TQString &deck,TQString &carddir, TQWidget *parent=0,
+ static int getCardDeck(TQString &deck,TQString &carddir, TQWidget *tqparent=0,
CardFlags flags=Both, bool* randomDeck=0,
bool* randomCardDir=0, double* scale=0, KConfig* conf=0);
@@ -103,11 +104,11 @@ public:
* Constructs a card deck selection dialog.
*
- * @param parent The parent widget of the dialog, if any.
+ * @param tqparent The tqparent widget of the dialog, if any.
* @param name The name of the dialog.
* @param flags Specifies whether the dialog is modal or not.
@@ -125,7 +126,7 @@ public:
* cards. The directory contains the card images as 1.png to 52.png
*
- * @param parent an optional pointer to the parent window of the dialog
+ * @param tqparent an optional pointer to the tqparent window of the dialog
*
* @param flags what to show